badwing.character package
=========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   badwing.character.controller

Submodules
----------

badwing.character.character module
----------------------------------

.. automodule:: badwing.character.character
   :members:
   :undoc-members:
   :show-inheritance:

badwing.character.kinematic module
----------------------------------

.. automodule:: badwing.character.kinematic
   :members:
   :undoc-members:
   :show-inheritance:

badwing.character.layer module
------------------------------

.. automodule:: badwing.character.layer
   :members:
   :undoc-members:
   :show-inheritance:

badwing.character.sprite module
-------------------------------

.. automodule:: badwing.character.sprite
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: badwing.character
   :members:
   :undoc-members:
   :show-inheritance:
